==> fet_5.11.0.orig.tar.gz: fet-5.11.0/src/interface/longtextmessagebox.h <==
/***************************************************************************
                          longtextmessagebox.cpp  -  description
                             -------------------
    begin                : 27 June 2009
    copyright            : (C) 2009 by Lalescu Liviu
    email                : Please see http://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef LONGTEXTMESSAGEBOX_H
#define LONGTEXTMESSAGEBOX_H

//#include <QDialog>
#include <QObject>

class QString;
class QWidget;


class LongTextMessageBox: public QObject
{
	Q_OBJECT
	
public:
	static int confirmation
	 ( QWidget * parent, const QString & title, const QString & text,
	 const QString& button0Text, const QString& button1Text, const QString& button2Text,
	 int defaultButton, int escapeButton );

	static int largeConfirmation
	 ( QWidget * parent, const QString & title, const QString & text,
	 const QString& button0Text, const QString& button1Text, const QString& button2Text,
	 int defaultButton, int escapeButton );

	static void information
	 ( QWidget * parent, const QString & title, const QString & text);

	static void largeInformation
	 ( QWidget * parent, const QString & title, const QString & text);

	static int confirmationWithDimensions
	 ( QWidget * parent, const QString & title, const QString & text,
	 const QString& button0Text, const QString& button1Text, const QString& button2Text,
	 int defaultButton, int escapeButton, int MINW, int MAXW, int MINH, int MAXH );

	static void informationWithDimensions
	 ( QWidget * parent, const QString & title, const QString & text, int MINW, int MAXW, int MINH, int MAXH);
};

#endif

==> fet_5.18.0.orig.tar.gz: fet-5.18.0/src/interface/longtextmessagebox.h <==
/*
File longtextmessagebox.h
*/

/***************************************************************************
                          longtextmessagebox.cpp  -  description
                             -------------------
    begin                : 27 June 2009
    copyright            : (C) 2009 by Lalescu Liviu
    email                : Please see http://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef LONGTEXTMESSAGEBOX_H
#define LONGTEXTMESSAGEBOX_H

#include <QObject>

class QString;
class QWidget;


class LongTextMessageBox: public QObject
{
	Q_OBJECT
	
public:
	static int confirmation
	 ( QWidget * parent, const QString & title, const QString & text,
	 const QString& button0Text, const QString& button1Text, const QString& button2Text,
	 int defaultButton, int escapeButton );

	static int largeConfirmation
	 ( QWidget * parent, const QString & title, const QString & text,
	 const QString& button0Text, const QString& button1Text, const QString& button2Text,
	 int defaultButton, int escapeButton );

	static int mediumConfirmation
	 ( QWidget * parent, const QString & title, const QString & text,
	 const QString& button0Text, const QString& button1Text, const QString& button2Text,
	 int defaultButton, int escapeButton );

	static void information
	 ( QWidget * parent, const QString & title, const QString & text);

	static void largeInformation
	 ( QWidget * parent, const QString & title, const QString & text);

	static void mediumInformation
	 ( QWidget * parent, const QString & title, const QString & text);

	static int confirmationWithDimensions
	 ( QWidget * parent, const QString & title, const QString & text,
	 const QString& button0Text, const QString& button1Text, const QString& button2Text,
	 int defaultButton, int escapeButton, int MINW, int MAXW, int MINH, int MAXH );

	static void informationWithDimensions
	 ( QWidget * parent, const QString & title, const QString & text, int MINW, int MAXW, int MINH, int MAXH);
};

#endif
